Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1853)

Unified Diff: gpu/ipc/service/image_transport_surface_delegate.h

Issue 2488413003: Mus: ImageTransportSurface should not depend on GpuChannelManager (Closed)
Patch Set: Fix windows compile issue Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: gpu/ipc/service/image_transport_surface_delegate.h
diff --git a/gpu/ipc/service/image_transport_surface_delegate.h b/gpu/ipc/service/image_transport_surface_delegate.h
index c8ad53bdb9151642b33abafebb6dedecf8fce44b..87c6cd0b502809412de34df1e3c4ffe1dec6c972 100644
--- a/gpu/ipc/service/image_transport_surface_delegate.h
+++ b/gpu/ipc/service/image_transport_surface_delegate.h
@@ -8,6 +8,7 @@
#include "base/callback.h"
#include "gpu/command_buffer/common/texture_in_use_response.h"
#include "gpu/gpu_export.h"
+#include "gpu/ipc/common/surface_handle.h"
#include "ui/events/latency_info.h"
#include "ui/gfx/swap_result.h"
@@ -49,7 +50,15 @@ struct GPU_EXPORT SwapBuffersCompleteParams {
class GPU_EXPORT ImageTransportSurfaceDelegate {
public:
- // Tells the delete that SwapBuffers returned and passes latency info.
+#if defined(OS_WIN)
+ // Tells the delegate that a child window was created with the provided
+ // SurfaceHandle.
+ virtual void DidCreateAcceleratedSurfaceChildWindow(
+ SurfaceHandle parent_window,
+ SurfaceHandle child_window) = 0;
+#endif
+
+ // Tells the delegate that SwapBuffers returned and passes latency info.
virtual void DidSwapBuffersComplete(SwapBuffersCompleteParams params) = 0;
// Returns the features available for the ContextGroup.
« no previous file with comments | « gpu/ipc/service/image_transport_surface_android.cc ('k') | gpu/ipc/service/image_transport_surface_linux.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698